<template>
  <div class="evaluate2">
    <div class="content">
      <div id="leftChart"></div>
      <div id="rightChart"></div>
    </div>
  </div>
</template>

<script>
export default {
  //import引入的组件需要注入到对象中才能使用
  components: {},
  data() {
    //这里存放数据
    return {};
  },
  //方法集合
  methods: {
    async drawLine() {
      const { data: dt } = await this.$http.get(
        "/jeecg-boot/output_street/outputStreet/queryall"
      );
      const { data: dt1 } = await this.$http.get(
        "/jeecg-boot/pollution_street/pollutionStreet/queryall"
      );
      this.upperoption(dt.result);
      this.loweroption(dt1.result);
    },
    upperoption(val) {
      // 基于准备好的dom，初始化echarts实例
      let leftChart = this.$echarts.init(document.getElementById("leftChart"));
      let upperoption = {
        baseOption: {
          //标题
          title: {
            top: "5%",
            text: "研发经费支出街道占比饼状图",

            left: "center",
            textStyle: {
              color: "#fff",
              fontSize: 25,
            },
          },

          //提示框
          tooltip: {
            trigger: "item",
            // 提示框浮层内容格式器 {a}（系列名称），{b}（数据项名称，{c}（数值, {d}（百分比）
            formatter: "{a} <br/>{b} : {c} ({d}%)",
          },
          legend: {
            orient: "horizontal",
            left: "left",
            top: "20%",
            textStyle: {
              color: "#fff",
              fontSize: 10,
            },
          },

          series: [
            {
              //标签
              label: {
                show: false,
                formatter: "{b}: {c} \n {d}%",
                fontSize: 20,
              },

              //标签线
              labelLine: {
                normal: {
                  show: false,
                },
                length: "10",
                length2: "10",
              },

              name: "研发经费支出街道占比饼状图",
              type: "pie",
              center: ["50%", "70%"],
              radius: "50%",
              data: val,
              color: [
                "#67AFEC",
                "#62DA8F",
                "#49dff0",
                "#2F64DB",
                "#35CABA",
                "#ACC0D6",
                "#EB9861",
                "#2C94ED",
                "#1C6EB4",
                "#699CD0",
                "#D4AAAA",
                "#5D748C",
                "#CDC9AC",
                "#7772C5",
                "#BAEBFF",
              ],
              itemStyle: {
                emphasis: {
                  shadowBlur: 10,
                  shadowOffsetX: 0,
                  shadowColor: "rgba(0, 0, 0, 0.5)",
                },
              },
            },
          ],
        },
        //媒体查询
        media: [
          {
            query: {
              minWidth: 550,
            },
            option: {
              title: {
                textStyle: {
                  fontSize: 15,
                },
              },
              legend: {
                orient: "vertical",
                left: "left",
                top: "20%",
                textStyle: {
                  color: "#fff",
                  fontSize: 10,
                },
              },
              series: [
                {
                  center: ["50%", "60%"],
                  radius: "50%",
                },
              ],
            },
          },
        ],
      };
      // 绘制图表
      leftChart.setOption(upperoption);
    },
    loweroption(val) {
      let rightChart = this.$echarts.init(
        document.getElementById("rightChart")
      );
      let loweroption = {
        baseOption: {
          //标题
          title: {
            top: "5%",
            text: "主要污染物排放总量街道占比饼状图",

            left: "center",
            textStyle: {
              color: "#fff",
              fontSize: 25,
            },
          },

          //提示框

          tooltip: {
            trigger: "item",
            // 提示框浮层内容格式器 {a}（系列名称），{b}（数据项名称，{c}（数值, {d}（百分比）
            formatter: "{a} <br/>{b} : {c} ({d}%)",
          },
          legend: {
            // orient: "vertical",
            orient: "horizontal",
            left: "left",
            top: "20%",
            textStyle: {
              fontSize: 15, //字体大小
              color: "#ffffff", //字体颜色
            },
          },

          series: [
            {
              //标签
              label: {
                show: false,
                formatter: "{b}: {c} \n {d}%",
                fontSize: 20,
              },
              //标签线
              labelLine: {
                // length: 10,
                // length2: 210,
                // minTurnAngle: 30,
                smooth: true,
                normal: {
                  show: false,
                },
              },
              name: "主要污染物排放总量街道占比饼状图",
              type: "pie",
              radius: "50%",
              center: ["50%", "70%"],
              //   roseType: "area",
              //   roseType: "radius",
              itemStyle: {
                borderRadius: 5,
              },
              data: val,
              color: [
                "#DACB75",
                "#82F0F7",
                "#8AC1A6",
                "#E67F7F",
                "#DFE66F",
                "#67ECD1",
                "#EB9861",
                "#2C94ED",
                "#1C6EB4",
                "#699CD0",
                "#D4AAAA",
                "#5D748C",
                "#DACB75",
                "#2E7CC5",
                "#B8AFE2",
              ],
              emphasis: {
                itemStyle: {
                  shadowBlur: 0,
                  shadowOffsetX: 0,
                  shadowColor: "rgba(0, 0, 0, 0.5)",
                },
              },
            },
          ],
        },

        labelLine: {
          length: "30",
          length2: "10",
        },

        //媒体查询
        media: [
          {
            query: {
              minWidth: 550,
            },
            option: {
              title: {
                textStyle: {
                  fontSize: 15,
                },
              },
              legend: {
                orient: "vertical",
                left: "left",
                top: "20%",
                textStyle: {
                  color: "#fff",
                  fontSize: 10,
                },
              },
              series: [
                {
                  center: ["50%", "65%"],
                  radius: "50%",
                },
              ],
            },
          },
        ],
      };
      rightChart.setOption(loweroption);
    },
  },
  mounted() {
    this.drawLine();
  },
  created() {},
};
</script>
<style lang="less" scoped>
//@import url(); 引入公共css类
.evaluate2 {
  height: 40%;
  background: rgba(8, 32, 58, 0.7);
  .content {
    width: 100%;
    height: 90%;
    box-sizing: border-box;
    display: flex;
    flex-wrap: wrap;
    justify-content: space-evenly;
    align-items: center;
    #leftChart {
      width: 49%;
      height: 100%;
    }
    #rightChart {
      width: 49%;
      height: 100%;
    }
  }
}
@media only screen and (max-width: 2560px) {
  .evaluate2 {
    overflow: visible;
    height: auto;
    background: transparent;
    .content {
      #leftChart {
        width: 100%;
        height: 2400px;
      }
      #rightChart {
        width: 100%;
        height: 2400px;
      }
    }
  }
}
</style>
